Developers
Tasks
All requests to tasks need to pass a project_id parameter except the list of tasks.
GET /tasks
Returns all tasks of current account.
{
"tasks": [
{
"task": {
...
}
},
...
]
}
<tasks>
<task>
...
</task>
...
</tasks>
GET /tasks/task_id
Returns a single task identified by its ID.
{
"task": {
...
}
}
<task>
...
</task>
POST /tasks
Create a new task
Request (cURL):
curl -d 'token=XXXXXXXXXXXX&api_key=XXXXXX&task[title]=task_title&task[description]=task_description&project_id=XX' https://www.triggerapp.com/api/v1/tasks
Parameters:
| Attribute | Required? | Type | Remarks |
|---|---|---|---|
| title | yes | string | title of the task |
| description | no | text | accepts Markdown formatting |
| assignee_id | no | integer | defaults to the owner of the project |
| status | no | string | possible values are new (default), in_progress, feedback, complete and on_hold |
| priority | no | integer | possible values are 0 (normal), 1 (high) and 2 (urgent) |
| billable | no | boolean | possible values are nil (default), true and false |
| hourly_rate | no | decimal | |
| flat_fee | no | decimal | |
| recurring_type | no | string | possible values are daily, weekly, monthly_by_number (specific day of the month), monthly_by_week_day (ie, 3rd Thursday), monthly_last_day, bimonthly, quarterly, biannually and yearly |
Response:
Returns status code 200 on success and the json or xml of the current task.
Failed requests will return 400.
PUT /tasks/task_id
Update an existing task
Request (cURL):
curl -d 'token=XXXXXXXXXXXX&api_key=XXXXXX&task[title]=task_title&task[description]=task_description&...' -X https://www.triggerapp.com/api/v1/tasks/task_id
Response:
Returns status code 200 on success and the json or xml of the current task.
Failed requests will return 400.
DELETE /tasks/task_id
Destroy an existing task
Request (cURL):
curl -d 'token=XXXXXXXXXXXX&api_key=XXXXXX' -X DELETE https://www.triggerapp.com/api/v1/tasks/task_id
Response:
Returns status code 204 on success and no content.
Failed requests will return 400.
Trigger is closing on 30 April 2027 and is no longer accepting new accounts. Existing customers can still sign in.